==> nextcloud-21.0.8p0.tgz: nextcloud/apps/updatenotification/l10n/hr.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} je dostupna. Saznajte više informacija o ažuriranju.",
    "Channel updated" : "Kanal je ažuriran",
    "Web updater is disabled" : "Web alat za ažuriranje je onemogućen",
    "Update notifications" : "Ažuriraj obavijesti",
    "The update server could not be reached since %d days to check for new updates." : "Nije moguće doći do poslužitelja za ažuriranje već %d dana radi provjeravanja za nova ažuriranja.",
    "Please check the Nextcloud and server log files for errors." : "Provjerite zapise Nextclouda i poslužitelja za moguće pogreške.",
    "Update to %1$s is available." : "Dostupno je ažuriranje na %1$s.",
    "Update for %1$s to version %2$s is available." : "Dostupno je ažuriranje za %1$s na inačicu %2$s.",
    "Update for {app} to version %s is available." : "Dostupno je ažuriranje za {app} na inačicu %s.",
    "Update notification" : "Ažuriraj obavijest",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Prikazuje obavijesti o ažuriranju za Nextcloud i pruža SSO za alat za ažuriranje.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Inačica koju upotrebljavajte više se ne održava. Obavezno ažurirajte na podržanu inačicu što je prije moguće.",
    "Apps missing compatible version" : "Aplikacije koje nemaju kompatibilnu inačicu",
    "View in store" : "Pogledajte u trgovini",
    "Apps with compatible version" : "Aplikacije koje imaju kompatibilnu inačicu",
    "Open updater" : "Otvori alat za ažuriranje",
    "Download now" : "Preuzmi sada",
    "Please use the command line updater to update." : "Ažurirajte putem naredbenog retka.",
    "What's new?" : "Što je novog?",
    "The update check is not yet finished. Please refresh the page." : "Provjera za ažuriranja još nije završena. Osvježite stranicu.",
    "Your version is up to date." : "Vaša je inačica ažurirana.",
    "A non-default update server is in use to be checked for updates:" : "Koristi se poslužitelj za ažuriranje koji nije zadan:",
    "Update channel:" : "Ažuriraj kanal:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Uvijek možete ažurirati na noviju inačicu. Ali nikad se ne možete vratiti na stabilniju inačicu.",
    "Notify members of the following groups about available updates:" : "Obavijestite članove sljedećih grupa o dostupnim ažuriranjima:",
    "Only notifications for app updates are available." : "Dostupne su samo obavijesti o ažuriranjima aplikacija.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Odabrani kanal za ažuriranje čini namjenske obavijesti za pojedini poslužitelj zastarjelim.",
    "The selected update channel does not support updates of the server." : "Odabrani kanal za ažuriranje ne podržava ažuriranja poslužitelja.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Dostupna je nova inačica: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Imajte na umu da se ažuriranje nakon novog izdanja pojavljuje tek nakon prve manje nove inačice ili kasnije. Nove inačice uvodimo u pravilnim vremenskim razmacima i ponekad preskočimo inačicu ako je problematična.",
    "Checked on {lastCheckedDate}" : "Provjereno {lastCheckedDate}",
    "Checking apps for compatible versions" : "Provjera aplikacija za kompatibilne verzije",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Provjerite da vaš config.php nije postavio <samp>appstoreenabled</samp> na vrijednost „netočno”.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Neuspješno povezivanje s trgovinom aplikacijama App Store ili je vraćena obavijest da nema ažuriranja. Ručno potražite ažuriranja ili provjerite ima li vaš poslužitelj pristup internetu i može li se povezati s trgovinom aplikacijama App Store.",
    "View changelog" : "Prikaži zapis promjena",
    "Enterprise" : "Enterprise",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Samo za poslovnu primjenu. Uvijek obuhvaća najnoviju razinu zakrpe, ali neće se odmah ažurirati na sljedeće veliko izdanje ili verziju. Ažuriranje se izvršava nakon dodatnih ispitivanja i provjera koje provodi Nextcloud GmbH kako bi osigurao primjereno skaliranje u kritičnim primjenama. Ovaj je kanal dostupan samo kupcima i sadrži paket Nextcloud Enterprise.",
    "Stable" : "Stabilna",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Najnovija stabilna inačica. Primjerena je za redovitu uporabu i uvijek će se ažurirati na najnoviju glavnu inačicu.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Razvojna inačica koja služi samo za ispitivanje novih značajki, a nikako za produkcijska okruženja.",
    "Apps missing updates" : "Aplikacijama nedostaju ažuriranja",
    "Apps with available updates" : "Aplikacije s dostupnim ažuriranjima",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Imajte na umu da se nova izdanja mogu pojaviti ovdje tek nakon nekog dužeg vremena. Nove inačice uvodimo u pravilnim vremenskim razmacima i ponekad preskočimo inačicu ako je problematična.",
    "Only notification for app updates are available." : "Dostupne su samo obavijesti o ažuriranjima aplikacija.",
    "Checking apps for compatible updates" : "Provjera aplikacija za kompatibilna ažuriranja",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Neuspješno povezivanje s trgovinom aplikacijama ili je trgovina aplikacijama vratila da nema ažuriranja. Ručno potražite ažuriranja ili provjerite ima li vaš poslužitelj pristup internetu i može li se povezati s trgovinom aplikacijama.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Sve</strong> aplikacije imaju dostupno ažuriranje za trenutnu inačicu",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> aplikacija nema dostupno ažuriranje za trenutnu inačicu","<strong>%n</strong> aplikacije nemaju dostupno ažuriranje za trenutnu inačicu","<strong>%n</strong> aplikacije nemaju dostupno ažuriranje za trenutnu inačicu"],
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available" : "<strong>Sve</strong> aplikacije imaju inačicu koja je kompatibilna s ovom inačicom Nextclouda",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available_::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available_" : ["<strong>%n</strong> aplikacija nema nijednu inačicu koja je kompatibilna s ovom inačicom Nextclouda","<strong>%n</strong> aplikacije nemaju nijednu inačicu koja je kompatibilna s ovom inačicom Nextclouda","<strong>%n</strong> aplikacija nema nijednu inačicu koja je kompatibilna s ovom inačicom Nextclouda"]
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-22.2.0.tgz: nextcloud/apps/updatenotification/l10n/hr.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} je dostupna. Saznajte više informacija o ažuriranju.",
    "Channel updated" : "Kanal je ažuriran",
    "Web updater is disabled" : "Web alat za ažuriranje je onemogućen",
    "Update notifications" : "Ažuriraj obavijesti",
    "The update server could not be reached since %d days to check for new updates." : "Nije moguće doći do poslužitelja za ažuriranje već %d dana radi provjeravanja za nova ažuriranja.",
    "Please check the Nextcloud and server log files for errors." : "Provjerite zapise Nextclouda i poslužitelja za moguće pogreške.",
    "Update to %1$s is available." : "Dostupno je ažuriranje na %1$s.",
    "Update for %1$s to version %2$s is available." : "Dostupno je ažuriranje za %1$s na inačicu %2$s.",
    "Update for {app} to version %s is available." : "Dostupno je ažuriranje za {app} na inačicu %s.",
    "Update notification" : "Ažuriraj obavijest",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Prikazuje obavijesti o ažuriranju za Nextcloud i pruža SSO za alat za ažuriranje.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Inačica koju upotrebljavajte više se ne održava. Obavezno ažurirajte na podržanu inačicu što je prije moguće.",
    "Apps missing compatible version" : "Aplikacije koje nemaju kompatibilnu inačicu",
    "View in store" : "Pogledajte u trgovini",
    "Apps with compatible version" : "Aplikacije koje imaju kompatibilnu inačicu",
    "Open updater" : "Otvori alat za ažuriranje",
    "Download now" : "Preuzmi sada",
    "Please use the command line updater to update." : "Ažurirajte putem naredbenog retka.",
    "What's new?" : "Što je novog?",
    "The update check is not yet finished. Please refresh the page." : "Provjera za ažuriranja još nije završena. Osvježite stranicu.",
    "Your version is up to date." : "Vaša je inačica ažurirana.",
    "A non-default update server is in use to be checked for updates:" : "Koristi se poslužitelj za ažuriranje koji nije zadan:",
    "Update channel:" : "Ažuriraj kanal:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Uvijek možete ažurirati na noviju inačicu. Ali nikad se ne možete vratiti na stabilniju inačicu.",
    "Notify members of the following groups about available updates:" : "Obavijestite članove sljedećih grupa o dostupnim ažuriranjima:",
    "Only notifications for app updates are available." : "Dostupne su samo obavijesti o ažuriranjima aplikacija.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Odabrani kanal za ažuriranje čini namjenske obavijesti za pojedini poslužitelj zastarjelim.",
    "The selected update channel does not support updates of the server." : "Odabrani kanal za ažuriranje ne podržava ažuriranja poslužitelja.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Dostupna je nova inačica: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Imajte na umu da se ažuriranje nakon novog izdanja pojavljuje tek nakon prve manje nove inačice ili kasnije. Nove inačice uvodimo u pravilnim vremenskim razmacima i ponekad preskočimo inačicu ako je problematična.",
    "Checked on {lastCheckedDate}" : "Provjereno {lastCheckedDate}",
    "Checking apps for compatible versions" : "Provjera aplikacija za kompatibilne verzije",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Provjerite da vaš config.php nije postavio <samp>appstoreenabled</samp> na vrijednost „netočno”.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Neuspješno povezivanje s trgovinom aplikacijama App Store ili je vraćena obavijest da nema ažuriranja. Ručno potražite ažuriranja ili provjerite ima li vaš poslužitelj pristup internetu i može li se povezati s trgovinom aplikacijama App Store.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available" : "<strong>Sve</strong> aplikacije imaju inačicu koja je kompatibilna s ovom inačicom Nextclouda",
    "View changelog" : "Prikaži zapis promjena",
    "Enterprise" : "Enterprise",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Samo za poslovnu primjenu. Uvijek obuhvaća najnoviju razinu zakrpe, ali neće se odmah ažurirati na sljedeće veliko izdanje ili verziju. Ažuriranje se izvršava nakon dodatnih ispitivanja i provjera koje provodi Nextcloud GmbH kako bi osigurao primjereno skaliranje u kritičnim primjenama. Ovaj je kanal dostupan samo kupcima i sadrži paket Nextcloud Enterprise.",
    "Stable" : "Stabilna",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Najnovija stabilna inačica. Primjerena je za redovitu uporabu i uvijek će se ažurirati na najnoviju glavnu inačicu.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Razvojna inačica koja služi samo za ispitivanje novih značajki, a nikako za produkcijska okruženja.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available_::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available_" : ["<strong>%n</strong> aplikacija nema nijednu inačicu koja je kompatibilna s ovom inačicom Nextclouda","<strong>%n</strong> aplikacije nemaju nijednu inačicu koja je kompatibilna s ovom inačicom Nextclouda","<strong>%n</strong> aplikacija nema nijednu inačicu koja je kompatibilna s ovom inačicom Nextclouda"],
    "Apps missing updates" : "Aplikacijama nedostaju ažuriranja",
    "Apps with available updates" : "Aplikacije s dostupnim ažuriranjima",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Imajte na umu da se nova izdanja mogu pojaviti ovdje tek nakon nekog dužeg vremena. Nove inačice uvodimo u pravilnim vremenskim razmacima i ponekad preskočimo inačicu ako je problematična.",
    "Only notification for app updates are available." : "Dostupne su samo obavijesti o ažuriranjima aplikacija.",
    "Checking apps for compatible updates" : "Provjera aplikacija za kompatibilna ažuriranja",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Neuspješno povezivanje s trgovinom aplikacijama ili je trgovina aplikacijama vratila da nema ažuriranja. Ručno potražite ažuriranja ili provjerite ima li vaš poslužitelj pristup internetu i može li se povezati s trgovinom aplikacijama.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Sve</strong> aplikacije imaju dostupno ažuriranje za trenutnu inačicu",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> aplikacija nema dostupno ažuriranje za trenutnu inačicu","<strong>%n</strong> aplikacije nemaju dostupno ažuriranje za trenutnu inačicu","<strong>%n</strong> aplikacije nemaju dostupno ažuriranje za trenutnu inačicu"]
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
